==> teal.widgets_0.4.1.tar.gz: teal.widgets/README.md <==
# teal.widgets

<!-- start badges -->
[![CRAN Version](https://www.r-pkg.org/badges/version/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Total Downloads](http://cranlogs.r-pkg.org/badges/grand-total/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Last Month Downloads](http://cranlogs.r-pkg.org/badges/last-month/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Last Week Downloads](http://cranlogs.r-pkg.org/badges/last-week/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)

[![Check 🛠](https://github.com/insightsengineering/teal.widgets/actions/workflows/check.yaml/badge.svg)](https://insightsengineering.github.io/teal.widgets/main/unit-test-report/)
[![Docs 📚](https://github.com/insightsengineering/teal.widgets/actions/workflows/docs.yaml/badge.svg)](https://insightsengineering.github.io/teal.widgets/)
[![Code Coverage 📔](https://raw.githubusercontent.com/insightsengineering/teal.widgets/_xml_coverage_reports/data/main/badge.svg)](https://insightsengineering.github.io/teal.widgets/main/coverage-report/)

![GitHub forks](https://img.shields.io/github/forks/insightsengineering/teal.widgets?style=social)
![GitHub repo stars](https://img.shields.io/github/stars/insightsengineering/teal.widgets?style=social)

![GitHub commit activity](https://img.shields.io/github/commit-activity/m/insightsengineering/teal.widgets)
![GitHub contributors](https://img.shields.io/github/contributors/insightsengineering/teal.widgets)
![GitHub last commit](https://img.shields.io/github/last-commit/insightsengineering/teal.widgets)
![GitHub pull requests](https://img.shields.io/github/issues-pr/insightsengineering/teal.widgets)
![GitHub repo size](https://img.shields.io/github/repo-size/insightsengineering/teal.widgets)
![GitHub language count](https://img.shields.io/github/languages/count/insightsengineering/teal.widgets)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Current Version](https://img.shields.io/github/r-package/v/insightsengineering/teal.widgets/main?color=purple\&label=package%20version)](https://github.com/insightsengineering/teal.widgets/tree/main)
[![Open Issues](https://img.shields.io/github/issues-raw/insightsengineering/teal.widgets?color=red\&label=open%20issues)](https://github.com/insightsengineering/teal.widgets/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc)
<!-- end badges -->

This package provides various widgets for `teal` applications. Examples include:

- `standard_layout` for a standard UI layout with output on the right and an encoding panel on the left
- `plot_with_settings` for a standard plot output UI with resizing and downloading options
- `table_with_setting` for a standard `rtables` output UI with download and pagination options
- `ggplot2_args` for a standard `ggplot2` output plot with graphic options
- `basic_table_args` for a standard `rtables` output table with graphic options

## Installation

```r
# stable versions
install.packages('teal.widgets', repos = c('https://insightsengineering.r-universe.dev', getOption('repos')))

# install.packages("pak")
pak::pak("insightsengineering/teal.widgets@*release")
```

Alternatively, you might want to use the development version available on [r-universe](https://r-universe.dev/).

```r
# beta versions
install.packages('teal.widgets', repos = c('https://pharmaverse.r-universe.dev', getOption('repos')))

# install.packages("pak")
pak::pak("insightsengineering/teal.widgets")
```

## Usage

To understand how to use this package, please refer to the [package website](https://insightsengineering.github.io/teal.widgets/), which provides multiple examples of code usage.

## Getting help

If you encounter a bug or you have a feature request - please file an issue. For questions, discussions and staying up to date, please use the "teal" channel in the [`pharmaverse` slack workspace](https://pharmaverse.slack.com).

## Stargazers and Forkers

### Stargazers over time

[![Stargazers over time](https://starchart.cc/insightsengineering/teal.widgets.svg)](https://starchart.cc/insightsengineering/teal.widgets)

### Stargazers

[![Stargazers repo roster for @insightsengineering/teal.widgets](https://reporoster.com/stars/insightsengineering/teal.widgets)](https://github.com/insightsengineering/teal.widgets/stargazers)

### Forkers

[![Forkers repo roster for @insightsengineering/teal.widgets](https://reporoster.com/forks/insightsengineering/teal.widgets)](https://github.com/insightsengineering/teal.widgets/network/members)

==> teal.widgets_0.4.2.tar.gz: teal.widgets/README.md <==
# teal.widgets

<!-- start badges -->
[![CRAN Version](https://www.r-pkg.org/badges/version/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Total Downloads](http://cranlogs.r-pkg.org/badges/grand-total/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Last Month Downloads](http://cranlogs.r-pkg.org/badges/last-month/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)
[![Last Week Downloads](http://cranlogs.r-pkg.org/badges/last-week/teal.widgets?color=green)](https://cran.r-project.org/package=teal.widgets)

[![Check 🛠](https://github.com/insightsengineering/teal.widgets/actions/workflows/check.yaml/badge.svg)](https://insightsengineering.github.io/teal.widgets/main/unit-test-report/)
[![Docs 📚](https://github.com/insightsengineering/teal.widgets/actions/workflows/docs.yaml/badge.svg)](https://insightsengineering.github.io/teal.widgets/)
[![Code Coverage 📔](https://raw.githubusercontent.com/insightsengineering/teal.widgets/_xml_coverage_reports/data/main/badge.svg)](https://insightsengineering.github.io/teal.widgets/main/coverage-report/)

![GitHub forks](https://img.shields.io/github/forks/insightsengineering/teal.widgets?style=social)
![GitHub repo stars](https://img.shields.io/github/stars/insightsengineering/teal.widgets?style=social)

![GitHub commit activity](https://img.shields.io/github/commit-activity/m/insightsengineering/teal.widgets)
![GitHub contributors](https://img.shields.io/github/contributors/insightsengineering/teal.widgets)
![GitHub last commit](https://img.shields.io/github/last-commit/insightsengineering/teal.widgets)
![GitHub pull requests](https://img.shields.io/github/issues-pr/insightsengineering/teal.widgets)
![GitHub repo size](https://img.shields.io/github/repo-size/insightsengineering/teal.widgets)
![GitHub language count](https://img.shields.io/github/languages/count/insightsengineering/teal.widgets)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Current Version](https://img.shields.io/github/r-package/v/insightsengineering/teal.widgets/main?color=purple\&label=package%20version)](https://github.com/insightsengineering/teal.widgets/tree/main)
[![Open Issues](https://img.shields.io/github/issues-raw/insightsengineering/teal.widgets?color=red\&label=open%20issues)](https://github.com/insightsengineering/teal.widgets/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc)
<!-- end badges -->

This package provides various widgets for `teal` applications. Examples include:

- `standard_layout` for a standard UI layout with output on the right and an encoding panel on the left
- `plot_with_settings` for a standard plot output UI with resizing and downloading options
- `table_with_setting` for a standard `rtables` output UI with download and pagination options
- `ggplot2_args` for a standard `ggplot2` output plot with graphic options
- `basic_table_args` for a standard `rtables` output table with graphic options

## Installation

```r
# stable versions
install.packages('teal.widgets')

# install.packages("pak")
pak::pak("insightsengineering/teal.widgets@*release")
```

Alternatively, you might want to use the development version available on [r-universe](https://r-universe.dev/).

```r
# beta versions
install.packages('teal.widgets', repos = c('https://pharmaverse.r-universe.dev', getOption('repos')))

# install.packages("pak")
pak::pak("insightsengineering/teal.widgets")
```

## Usage

To understand how to use this package, please refer to the [package website](https://insightsengineering.github.io/teal.widgets/), which provides multiple examples of code usage.

## Getting help

If you encounter a bug or you have a feature request - please file an issue. For questions, discussions and staying up to date, please use the "teal" channel in the [`pharmaverse` slack workspace](https://pharmaverse.slack.com).

## Stargazers and Forkers

### Stargazers over time

[![Stargazers over time](https://starchart.cc/insightsengineering/teal.widgets.svg)](https://starchart.cc/insightsengineering/teal.widgets)

### Stargazers

[![Stargazers repo roster for @insightsengineering/teal.widgets](http://reporoster.com/stars/insightsengineering/teal.widgets)](https://github.com/insightsengineering/teal.widgets/stargazers)

### Forkers

[![Forkers repo roster for @insightsengineering/teal.widgets](http://reporoster.com/forks/insightsengineering/teal.widgets)](https://github.com/insightsengineering/teal.widgets/network/members)
